import { defineComponent, inject, computed, ref, createVNode } from 'vue';
import useMemo from '../_util/hooks/useMemo.js';
import { radioGroupContext } from './Group.js';

const RadioProps = {
  prefixCls: {
    default: "x-radio"
  },
  checked: Boolean,
  disabled: Boolean,
  name: String,
  value: [String, Number]
};
var Radio = defineComponent({
  name: "x-radio",
  props: RadioProps,
  emits: ["update:checked", "change"],
  setup(props, {
    emit,
    slots
  }) {
    const groupContext = inject(radioGroupContext);
    const disabled = useMemo(() => {
      var _a;
      return ((_a = groupContext == null ? void 0 : groupContext.disabledRef) == null ? void 0 : _a.value) || props.disabled;
    });
    const name = useMemo(() => {
      var _a;
      return ((_a = groupContext == null ? void 0 : groupContext.nameRef) == null ? void 0 : _a.value) || props.name;
    });
    const checked = useMemo(() => props.checked);
    const _checked = computed(() => {
      if (groupContext)
        return groupContext.valueRef.value == props.value;
      return checked.value;
    });
    function onChange(e) {
      if (props.disabled)
        return;
      if (groupContext) {
        groupContext.onChange(props.value);
      } else {
        const val = e.target.checked;
        checked.value = val;
        emit("update:checked", val);
      }
      emit("change", props.value);
    }
    const focused = ref(false);
    function onFocus() {
      focused.value = true;
    }
    function onBlur() {
      focused.value = false;
    }
    return () => {
      var _a;
      const {
        prefixCls
      } = props;
      const radioProps = {
        class: [prefixCls, {
          [`${prefixCls}-checked`]: _checked.value,
          [`${prefixCls}-focused`]: focused.value,
          [`${prefixCls}-disabled`]: disabled.value
        }]
      };
      const inputProps = {
        class: `${prefixCls}_input`,
        name: name.value,
        value: props.value,
        type: "radio",
        checked: !!_checked.value,
        disabled: disabled.value,
        onFocus,
        onBlur,
        onChange
      };
      return createVNode("label", radioProps, [createVNode("input", inputProps, null), createVNode("div", {
        "class": `${prefixCls}_dot`
      }, null), createVNode("div", {
        "class": `${prefixCls}_label`
      }, [(_a = slots.default) == null ? void 0 : _a.call(slots)])]);
    };
  }
});

export { RadioProps, Radio as default };
